from setuptools import setup

setup(
     name='ecotron-app',    # This is the name of your PyPI-package.
     version='0.1',                          # Update the version number for new releases
     scripts=['app'],                  # The name of your scipt, and also the command you'll be using for calling it
     url='https://github.com/nanusefue/econtro-app',
     author='Esteban Gimenez - nanusefue',
     author_email='nanusefue@gmail.com',


)